@@ -135,7 +135,7 @@ class OSSUtils:
                 self.client.delete_object(obj.key)
             return True
         except Exception as e:
-            feishu_alert.send(traceback.format_exc())
+            print(traceback.format_exc())
             return False
 
     def ls(self, prefix):
@@ -206,7 +206,7 @@ class OSSUtils:
                 return True
             return False
         except Exception as e:
-            feishu_alert.send(traceback.format_exc())
+            print(traceback.format_exc())
             return False
 
     def download_object(self, prefix, dir_path):
@@ -231,7 +231,7 @@ class OSSUtils:
             self.client.get_object_to_file(prefix, download_path)
             return True
         except Exception as e:
-            feishu_alert.send(f"oss download_object error: {traceback.format_exc()}")
+            print(f"oss download_object error: {traceback.format_exc()}")
             return False
 
     def upload_object(self, prefix, local_path):
@@ -255,7 +255,7 @@ class OSSUtils:
             )
             return True
         except Exception as e:
-            feishu_alert.send(traceback.format_exc())
+            print(traceback.format_exc())
             return False
 
     def copy_object(self, prefix, target_prefix):
@@ -274,7 +274,7 @@ class OSSUtils:
             )
             return True
         except Exception as e:
-            feishu_alert.send(traceback.format_exc())
+            print(traceback.format_exc())
             return False
 
     def generate_presigned_url(self, prefix, expires_in=60 * 60 * 24):
